@@ -18,7 +18,7 @@ limitations under the License.
 @copyright: 2012 Research Institute eAustria
 '''
 
-from jsonrpc2 import JsonRpcBase, JsonRpcException
+from jsonrpc2 import JsonRpcBase, JsonRpcException, JsonRpc
 import functools
 import uuid
 import socket
@@ -26,6 +26,7 @@ import json
 import logging
 import SocketServer
 import threading
+import urllib2
 
 
 class RPCException(Exception):
@@ -116,7 +117,8 @@ def isrpcmethod(obj):
 def build_exception(msg, extra = None):
     code = msg['code']
     message = msg["message"]
-    text = "(%d) %s" % (code, message)
+    data = msg["data"]
+    text = "(%d) %s (%s)" % (code, message, data)
     if extra is not None:
         text = text + ": %s" % extra
     exception = RPCException(text)
@@ -194,10 +196,35 @@ class DummyTransport(object):
             rez = e.as_dict()
         return rez
 
+class HTTPTransport(object):
+    log = logging.getLogger("HTTPTransport")
+    def __init__(self, endpoint):
+        self._endpoint = endpoint
+
+    def rpc_send_message(self, msg):
+        self.log.debug("Message for sending: %s", msg)
+        req = urllib2.Request(self._endpoint.geturl())
+        req.add_data(json.dumps(msg).encode("utf-8"))
+        req.add_header('Content-Type', 'application/json')
+        result = urllib2.urlopen(req)
+
+        if 'content-type' not in result.headers:
+            self.log.error("No content type received from server")
+            return
+
+        self.log.error("Server Status Code is: %d", result.getcode())
+        if result.getcode() == 200:
+            result_data = result.read()
+            result_json = json.loads(result_data)
+            return result_json
+        else:
+            self.log.critical("Status code received from server (%d) is not supported", result.getcode())
+
+
 class UnixStreamTransport(object):
     log = logging.getLogger("UnixStreamTransport")
     def __init__(self, endpoint):
-        self._endpoint = endpoint
+        self._endpoint = endpoint.path
 
     def rpc_send_message(self, msg):
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
